@@ -118,18 +118,24 @@ int confirm( Font *font, char *str, int type )
 					}
                 }
                 else
-                switch (event.key.keysym.sym) {
-                    case SDLK_y:
+                    if (event.key.keysym.sym == SDLK_ESCAPE) {
+                        // ESC always returns false
                         go_on = 0;
-                        ret = 1;
-                        break;
-                    case SDLK_ESCAPE:
-                    case SDLK_n:
-                        go_on = 0;
-                        ret = 0;
-                    default:
-                        break;
-                }
+                        ret = 0;					
+                    } else {
+                        // check pressed key against yes/no letters
+                        char *keyName = SDL_GetKeyName(event.key.keysym.sym);
+                        char *yesLetter = _("y");
+                        char *noLetter = _("n");
+                        if (strcmp(keyName, yesLetter) == 0) {
+                            go_on = 0;
+                            ret = 1;
+                        }
+                        if (strcmp(keyName, noLetter) == 0) {
+                            go_on = 0;
+                            ret = 0;
+                        }
+                    }
                 break;
         }
     }
